# Tools for phase and frequency data

## Installation

```
git clone https://github.com/bleykauf/freqtools
cd freqtools
pip install -e .
```

The option `-e` installs `freqtools` in editable mode, i.e. changes made to the files
will automatically be applied.

## Features

The main feature are simple conversion between power and amplitude spectral densities as shown in this diagram.

![svg](./docs/representations.svg)

The other features are shown in the Example section below.

## Examples

An example notebook can be found [here](examples/Examples.ipynb).
